@@ -11,7 +11,7 @@ def __decode_and_decompress(url):
 
 
 def __get_index_file():
-    index = __decode_and_decompress("http://107.175.127.29/index.json.gz")
+    index = __decode_and_decompress("http://107.175.127.29/index/index.json.gz")
 
     return index
 
